@@ -55,7 +55,7 @@ class __ITU1853():
     def rain_attenuation_synthesis(self, lat, lon, f, el, hs, Ns,
                                    Ts=1, tau=45, n=None):
         return self.instance.rain_attenuation_synthesis(
-                lat, lon, f, el, hs, Ns, Ts=Ts, tau=tau, n=n)
+            lat, lon, f, el, hs, Ns, Ts=Ts, tau=tau, n=n)
 
     def total_attenuation_synthesis(self, lat, lon, f, el, p, D, Ns, Ts=1,
                                     tau=45, hs=None, eta=0.65, rho=None,
@@ -67,15 +67,15 @@ class __ITU1853():
 
     def scintillation_attenuation_synthesis(self, Ns, f_c=0.1, Ts=1):
         return self.instance.scintillation_attenuation_synthesis(
-                Ns, f_c=f_c, Ts=Ts)
+            Ns, f_c=f_c, Ts=Ts)
 
     def cloud_liquid_water_synthesis(self, lat, lon, Ns, Ts=1, n=None):
         return self.instance.cloud_liquid_water_synthesis(
-                lat, lon, Ns, Ts=Ts, n=n)
+            lat, lon, Ns, Ts=Ts, n=n)
 
     def integrated_water_vapour_synthesis(self, lat, lon, Ns, Ts=1, n=None):
         return self.instance.integrated_water_vapour_synthesis(
-                lat, lon, Ns, Ts=Ts, n=n)
+            lat, lon, Ns, Ts=Ts, n=n)
 
 
 class _ITU1853_1():
@@ -143,12 +143,12 @@ class _ITU1853_1():
 
         # D6: Discard the first 200 000 samples from the synthesized
         if discard_samples:
-            A_rain = A_rain[np.ceil(200000/Ts).astype(int):]
+            A_rain = A_rain[np.ceil(200000 / Ts).astype(int):]
 
         return A_rain.flatten()
 
-    @staticmethod
-    def fftnoise(f):
+    @classmethod
+    def fftnoise(cls, f):
         f = np.array(f, dtype='complex')
         Np = (len(f) - 1) // 2
         phases = np.random.rand(Np) * 2 * np.pi
@@ -157,7 +157,8 @@ class _ITU1853_1():
         f[-1:-1 - Np:-1] = np.conj(f[1:Np + 1])
         return np.fft.ifft(f).real
 
-    def scintillation_attenuation_synthesis(self, Ns, f_c=0.1, Ts=1):
+    @staticmethod
+    def scintillation_attenuation_synthesis(Ns, f_c=0.1, Ts=1):
         """
         For Earth-space paths, the time series synthesis method is valid for
         frequencies between 4 GHz and 55 GHz and elevation angles between
@@ -167,7 +168,7 @@ class _ITU1853_1():
         H_f = np.where(freqs <= f_c, 1, 10 **
                        ((np.log10(freqs) - np.log10(f_c)) * (-8 / 3)))
         H_f = H_f[0:int(Ns + 2e5)]
-        sci = self.fftnoise(np.fft.fftshift(H_f))
+        sci = _ITU1853_1.fftnoise(np.fft.fftshift(H_f))
         return sci[200000:].flatten()
 
     @staticmethod
@@ -212,7 +213,7 @@ class _ITU1853_1():
 
         # D6: Discard the first 500 000 samples from the synthesized
         if discard_samples:
-            L = L[np.ceil(500000/Ts).astype(int):]
+            L = L[np.ceil(500000 / Ts).astype(int):]
 
         return L.flatten()
 
@@ -227,7 +228,7 @@ class _ITU1853_1():
         ln_Vi = np.log(Vi)
 
         a, b = np.linalg.lstsq(np.vstack([ln_Vi, np.ones(len(ln_Vi))]).T,
-                               ln_lnPi)[0]
+                               ln_lnPi, rcond=None)[0]
         kappa = a
         lambd = np.exp(-b / a)
         return kappa, lambd
@@ -255,7 +256,7 @@ class _ITU1853_1():
         V = lambd * (- np.log10(stats.norm.sf(G_v)))**(1 / kappa)
         # Step C5: Discard the first 5 000 000 samples from the synthesized
         if discard_samples:
-            V = V[np.ceil(5000000/Ts).astype(int):]
+            V = V[np.ceil(5000000 / Ts).astype(int):]
 
         return V.flatten()
 
@@ -304,7 +305,7 @@ class _ITU1853_1():
         # Step C9: Identify time stamps where A_R > 0 L > 1
         idx = np.where(np.logical_and(Ar > 0, L > 1))[0]
         idx_no = np.where(np.logical_not(
-                    np.logical_and(Ar > 0, L > 1)))[0]
+            np.logical_and(Ar > 0, L > 1)))[0]
 
         # Step C10: Discard the previous values of Ac and re-compute them by
         # linear interpolation vs. time starting from the non-discarded cloud
@@ -334,7 +335,7 @@ class _ITU1853_1():
 
         e = Tm * rho / 216.7
         go = gamma0_exact(f, P, rho, Tm).value
-        ho, _ = slant_inclined_path_equivalent_height(f, P + e).value
+        ho, _ = slant_inclined_path_equivalent_height(f, P + e, rho).value
         Ao = ho * go * np.ones_like(Ar)
 
         # Step C15: Synthesize unit variance scintillation time series
@@ -418,6 +419,7 @@ def change_version(new_version):
         Number of the version to use.
         Valid values are:
           * 1:  Activates recommendation ITU-R P.1853-1 (02/12) (Current version)
+          * 0:  Activates recommendation ITU-R P.1853-0 (10/09) (Superseded)
     """
     global __model
     __model = __ITU1853(new_version)
@@ -426,11 +428,29 @@ def change_version(new_version):
 def get_version():
     """
     Obtain the version of the ITU-R P.1853 recommendation currently being used.
+
+    Returns
+    -------
+    version: int
+        Version currently being used.
+
     """
     global __model
     return __model.__version__
 
 
+def set_seed(seed):
+    """
+    Set the seed used to generate random numbers.
+
+    Parameters
+    ----------
+    seed : int
+        Seed used to generate random numbers
+    """
+    __model.set_seed(seed)
+
+
 def rain_attenuation_synthesis(lat, lon, f, el, hs, Ns, Ts=1, tau=45, n=None):
     """
     A method to generate a synthetic time series of rain attenuation values.
@@ -480,7 +500,7 @@ def rain_attenuation_synthesis(lat, lon, f, el, hs, Ns, Ts=1, tau=45, n=None):
     el = prepare_quantity(el, u.deg, 'Elevation angle')
     hs = prepare_quantity(
         hs, u.km, 'Heigh above mean sea level of the earth station')
-    Ts = prepare_quantity(f, u.second, 'Time step between samples')
+    Ts = prepare_quantity(Ts, u.second, 'Time step between samples')
     val = __model.rain_attenuation_synthesis(lat, lon, f, el, hs, Ns,
                                              Ts=Ts, tau=tau, n=n)
     return val * u.dB
@@ -592,7 +612,7 @@ def cloud_liquid_water_synthesis(lat, lon, Ns, Ts=1, n=None):
 
 
 def total_attenuation_synthesis(lat, lon, f, el, p, D, Ns, Ts=1, hs=None,
-                                tau=45, eta=0.65,  rho=None, H=None, P=None,
+                                tau=45, eta=0.65, rho=None, H=None, P=None,
                                 hL=1000, return_contributions=False):
     """ The time series synthesis method generates a time series that
     reproduces the spectral characteristics, rate of change and duration
@@ -675,8 +695,8 @@ def total_attenuation_synthesis(lat, lon, f, el, p, D, Ns, Ts=1, hs=None,
     hL = prepare_quantity(hL, u.m, 'Height of the turbulent layer')
 
     val = __model.total_attenuation_synthesis(
-            lat, lon, f, el, p, D, Ns, Ts=Ts, tau=tau, hs=hs, eta=eta, rho=rho,
-            H=H, P=P, hL=hL, return_contributions=return_contributions)
+        lat, lon, f, el, p, D, Ns, Ts=Ts, tau=tau, hs=hs, eta=eta, rho=rho,
+        H=H, P=P, hL=hL, return_contributions=return_contributions)
     if return_contributions:
         return tuple([v * u.dB for v in val])
     else:
