@@ -9,7 +9,7 @@ from astropy import units as u
 
 from itur.models.itu1144 import bilinear_2D_interpolator
 from itur.utils import (prepare_input_array, prepare_quantity, load_data,
-                        prepare_output_array, dataset_dir)
+                        prepare_output_array, dataset_dir, get_input_type)
 
 
 class __ITU453__():
@@ -141,7 +141,7 @@ class _ITU453_13_():
 
         lon[lon > 180] = lon[lon > 180] - 360
         return self._N_wet[float(p)](
-                np.array([lat.ravel(), lon.ravel()]).T).reshape(lat.shape)
+            np.array([lat.ravel(), lon.ravel()]).T).reshape(lat.shape)
 
     @classmethod
     def wet_term_radio_refractivity(self, e, T):
@@ -168,15 +168,15 @@ class _ITU453_13_():
     def saturation_vapour_pressure(self, T, P, type_hydrometeor='water'):
 
         if type_hydrometeor == 'water':
-            EF = 1 + 1e-4 * (7.2 + P * (0.00320 + 5.9e-6 * T**2))
+            EF = 1 + 1e-4 * (7.2 + P * (0.0320 + 5.9e-6 * T**2))
             a = 6.1121
             b = 18.678
             c = 257.14
             d = 234.5
 
         elif type_hydrometeor == 'ice':
-            EF = 1 + 1e-4 * (2.2 + P * (0.00382 + 6.4e-7 * T**2))
-            a = 6.11215
+            EF = 1 + 1e-4 * (2.2 + P * (0.0383 + 6.4e-6 * T**2))
+            a = 6.1115
             b = 23.036
             c = 279.82
             d = 333.7
@@ -540,7 +540,7 @@ def map_wet_term_radio_refractivity(lat, lon, p=50):
     [1] The radio refractive index: its formula and refractivity data
     https://www.itu.int/rec/R-REC-P.453/en
     """
-    type_output = type(lat)
+    type_output = get_input_type(lat)
     lat = prepare_input_array(lat)
     lon = prepare_input_array(lon)
     lon = np.mod(lon, 360)
@@ -576,7 +576,7 @@ def DN65(lat, lon, p):
     https://www.itu.int/rec/R-REC-P.453/en
 
     """
-    type_output = type(lat)
+    type_output = get_input_type(lat)
     lat = prepare_input_array(lat)
     lon = prepare_input_array(lon)
     lon = np.mod(lon, 360)
@@ -609,7 +609,7 @@ def DN1(lat, lon, p):
     [1] The radio refractive index: its formula and refractivity data
     https://www.itu.int/rec/R-REC-P.453/en
     """
-    type_output = type(lat)
+    type_output = get_input_type(lat)
     lat = prepare_input_array(lat)
     lon = prepare_input_array(lon)
     lon = np.mod(lon, 360)
