@@ -9,7 +9,6 @@ import scipy.special
 import scipy.integrate
 from astropy import units as u
 
-from itur import utils
 from itur.models.itu453 import water_vapour_pressure,\
     wet_term_radio_refractivity, map_wet_term_radio_refractivity
 from itur.models.itu837 import rainfall_rate, rainfall_probability
@@ -17,7 +16,7 @@ from itur.models.itu838 import rain_specific_attenuation
 from itur.models.itu839 import rain_height
 from itur.models.itu1511 import topographic_altitude
 from itur.utils import prepare_input_array, prepare_output_array,\
-    prepare_quantity, compute_distance_earth_to_earth
+    prepare_quantity, compute_distance_earth_to_earth, get_input_type
 
 import warnings
 
@@ -151,7 +150,7 @@ class _ITU618():
                                                lat2, lon2, a2, el2, f, tau=45,
                                                hs1=None, hs2=None):
         fcn = np.vectorize(
-                self.instance.site_diversity_rain_outage_probability)
+            self.instance.site_diversity_rain_outage_probability)
         return np.array(fcn(lat1, lon1, a1, el1,
                             lat2, lon2, a2, el2,
                             f, tau, hs1, hs2).tolist())
@@ -184,7 +183,7 @@ class _ITU618_13():
             Ls = np.where(
                 el >= 5, (hr - hs) / (np.sin(np.deg2rad(el))),         # Eq. 1
                 2 * (hr - hs) / (((np.sin(np.deg2rad(el)))**2 +
-                2 * (hr - hs) / Re)**0.5 + (np.sin(np.deg2rad(el)))))  # Eq. 2
+                                  2 * (hr - hs) / Re)**0.5 + (np.sin(np.deg2rad(el)))))  # Eq. 2
 
         # Step 3: Calculate the horizontal projection, LG, of the
         # slant-path length
@@ -271,7 +270,7 @@ class _ITU618_13():
             Ls = np.where(
                 el >= 5, (hr - hs) / (np.sin(np.deg2rad(el))),         # Eq. 1
                 2 * (hr - hs) / (((np.sin(np.deg2rad(el)))**2 +
-                2 * (hr - hs) / Re)**0.5 + (np.sin(np.deg2rad(el)))))  # Eq. 2
+                                  2 * (hr - hs) / Re)**0.5 + (np.sin(np.deg2rad(el)))))  # Eq. 2
 
         d = Ls * np.cos(np.deg2rad(el))
         rho = 0.59 * np.exp(-abs(d) / 31) + 0.41 * np.exp(-abs(d) / 800)
@@ -339,7 +338,7 @@ class _ITU618_13():
             lat1, lon1, f, el1, hs1, P_1 * 100, tau)
 
         sigma_lna2, m_lna2 = self.fit_rain_attenuation_to_lognormal(
-            lat2, lon2, f, el2, hs1, P_2 * 100, tau)
+            lat2, lon2, f, el2, hs2, P_2 * 100, tau)
 
         rho_a = 0.94 * np.exp(-d / 30) + 0.06 * np.exp(-(d / 500)**2)
         lim_1 = (np.log(a1) - m_lna1) / sigma_lna1
@@ -435,12 +434,11 @@ class _ITU618_13():
             # polarization tilt angle can be scaled to another frequency and
             # polarization tilt angle using the semi-empirical formula:
             XPD_p = XPD_p - 20 * np.log10(
-              f_orig * np.sqrt(1 - 0.484 * (1 - np.cos(np.deg2rad(4 * tau)))) /
-              (f * np.sqrt(1 - 0.484 * (1 - np.cos(np.deg2rad(4 * tau))))))
+                f_orig * np.sqrt(1 - 0.484 * (1 + np.cos(np.deg2rad(4 * tau)))) /
+                (f * np.sqrt(1 - 0.484 * (1 + np.cos(np.deg2rad(4 * tau))))))
         return XPD_p
 
     @classmethod
-
     def scintillation_attenuation_sigma(self, lat, lon, f, el, p, D, eta=0.5,
                                         T=None, H=None, P=None, hL=1000):
         # Step 1: For the value of t, calculate the saturation water vapour
@@ -702,7 +700,7 @@ def rain_attenuation(lat, lon, f, el, hs=None, p=0.01, R001=None,
     Earth-space telecommunication systems:
     https://www.itu.int/dms_pubrec/itu-r/rec/p/R-REC-P.618-12-201507-I!!PDF-E.pdf
     """
-    type_output = type(lat)
+    type_output = get_input_type(lat)
 
     lat = prepare_input_array(lat)
     lon = prepare_input_array(lon)
@@ -761,7 +759,7 @@ def rain_attenuation_probability(lat, lon, el, hs=None, Ls=None, P0=None):
     Earth-space telecommunication systems:
     https://www.itu.int/dms_pubrec/itu-r/rec/p/R-REC-P.618-12-201507-I!!PDF-E.pdf
     """
-    type_output = type(lat)
+    type_output = get_input_type(lat)
 
     lat = prepare_input_array(lat)
     lon = prepare_input_array(lon)
@@ -840,7 +838,7 @@ def site_diversity_rain_outage_probability(lat1, lon1, a1, el1, lat2,
     Earth-space telecommunication systems:
     https://www.itu.int/dms_pubrec/itu-r/rec/p/R-REC-P.618-12-201507-I!!PDF-E.pdf
     """
-    type_output = type(lat1)
+    type_output = get_input_type(lat1)
     lon1 = np.mod(lon1, 360)
     lat1 = prepare_quantity(lat1, u.deg, 'Latitude in ground station 1')
     lon1 = prepare_quantity(lon1, u.deg, 'Longitude in ground station 1')
@@ -914,7 +912,7 @@ def scintillation_attenuation(lat, lon, f, el, p, D, eta=0.5, T=None,
     Earth-space telecommunication systems:
     https://www.itu.int/dms_pubrec/itu-r/rec/p/R-REC-P.618-12-201507-I!!PDF-E.pdf
     """
-    type_output = type(lat)
+    type_output = get_input_type(lat)
 
     lat = prepare_input_array(lat)
     lon = prepare_input_array(lon)
@@ -984,7 +982,7 @@ def scintillation_attenuation_sigma(lat, lon, f, el, p, D, eta=0.5, T=None,
     Earth-space telecommunication systems:
     https://www.itu.int/dms_pubrec/itu-r/rec/p/R-REC-P.618-12-201507-I!!PDF-E.pdf
     """
-    type_output = type(lat)
+    type_output = get_input_type(lat)
 
     lat = prepare_input_array(lat)
     lon = prepare_input_array(lon)
@@ -1042,7 +1040,7 @@ def rain_cross_polarization_discrimination(Ap, f, el, p, tau=45):
     Earth-space telecommunication systems:
     https://www.itu.int/dms_pubrec/itu-r/rec/p/R-REC-P.618-12-201507-I!!PDF-E.pdf
     """
-    type_output = type(Ap)
+    type_output = get_input_type(Ap)
     Ap = prepare_input_array(Ap)
     f = prepare_quantity(f, u.GHz, 'Frequency')
     el = prepare_quantity(el, u.deg, 'Elevation angle')
