@@ -15,7 +15,7 @@ from itur.models.itu835 import (standard_pressure, standard_temperature,
                                 standard_water_vapour_density)
 from itur.models.itu836 import total_water_vapour_content
 from itur.models.itu1511 import topographic_altitude
-from itur.utils import (prepare_quantity, prepare_output_array,
+from itur.utils import (prepare_quantity, prepare_output_array, get_input_type,
                         prepare_input_array, load_data, dataset_dir)
 
 
@@ -146,8 +146,10 @@ class __ITU676__():
         fcn = np.vectorize(self.instance.gaseous_attenuation_terrestrial_path)
         return fcn(r, f, el, rho, P, T, mode)
 
-    def gaseous_attenuation_inclined_path(self, f, el, rho, P, T, h1, h2, mode):
-        # Abstract method to compute the gaseous attenuation over an inclined path
+    def gaseous_attenuation_inclined_path(
+            self, f, el, rho, P, T, h1, h2, mode):
+        # Abstract method to compute the gaseous attenuation over an inclined
+        # path
         fcn = np.vectorize(self.instance.gaseous_attenuation_inclined_path)
         return fcn(f, el, rho, P, T, h1, h2, mode)
 
@@ -156,10 +158,10 @@ class __ITU676__():
         fcn = np.vectorize(self.instance.gaseous_attenuation_slant_path)
         return fcn(f, el, rho, P, T, V_t, h, mode)
 
-    def slant_inclined_path_equivalent_height(self, f, p):
+    def slant_inclined_path_equivalent_height(self, f, p, rho, T):
         fcn = np.vectorize(self.instance.slant_inclined_path_equivalent_height,
                            excluded=[0], otypes=[np.ndarray])
-        return np.array(fcn(f, p).tolist())
+        return np.array(fcn(f, p, rho, T).tolist())
 
     def zenit_water_vapour_attenuation(
             self, lat, lon, p, f, V_t=None, h=None):
@@ -256,18 +258,18 @@ class _ITU676_12_():
 
     def gammaw_approx(self, f, p, rho, T):
         warnings.warn(
-                RuntimeWarning(
-                    'Recommendation ITU-R P.676-12 does not have an explicit '
-                    'method to approximate gamma_w. The exact method shall be '
-                    'used instead.'))
+            RuntimeWarning(
+                'Recommendation ITU-R P.676-12 does not have an explicit '
+                'method to approximate gamma_w. The exact method shall be '
+                'used instead.'))
         return self.gamma_exact(f, p, rho, T)
 
     def gamma0_approx(self, f, p, rho, T):
         warnings.warn(
-                RuntimeWarning(
-                    'Recommendation ITU-R P.676-12 does not have an explicit '
-                    'method to approximate gamma_w. The exact method shall be '
-                    'used instead.'))
+            RuntimeWarning(
+                'Recommendation ITU-R P.676-12 does not have an explicit '
+                'method to approximate gamma_w. The exact method shall be '
+                'used instead.'))
         return self.gamma_exact(f, p, rho, T)
 
     @classmethod
@@ -285,9 +287,6 @@ class _ITU676_12_():
 
     @classmethod
     def gaseous_attenuation_approximation(self, f, el, rho, P, T):
-        """
-        T goes in Kelvin
-        """
         if np.any(f > 350):
             warnings.warn(
                 RuntimeWarning(
@@ -384,15 +383,17 @@ class _ITU676_12_():
             return (A0 + Aw) / np.sin(np.deg2rad(el))
 
         else:
-            delta_h = 0.0001 * np.exp((np.arange(0, 923)) / 100)
-            h_n = np.cumsum(delta_h)
+            delta_h = 0.0001 * \
+                np.exp((np.arange(0, 922)) / 100)             # Eq. 14
+            h_n = 0.0001 * ((np.exp(np.arange(0, 922) / 100.0) -
+                             1.0) / (np.exp(1.0 / 100.0) - 1.0))             # Eq. 15
             T_n = standard_temperature(h_n).to(u.K).value
             press_n = standard_pressure(h_n).value
             rho_n = standard_water_vapour_density(h_n, rho_0=rho).value
 
-            e = rho * T / 216.7
-            n_n = radio_refractive_index(press_n, e, T).value
-            n_ratio = np.pad(n_n[1:], (0, 1), mode='edge') / n_n
+            e_n = rho_n * T_n / 216.7
+            n_n = radio_refractive_index(press_n, e_n, T_n).value
+            n_ratio = n_n / np.pad(n_n[1:], (0, 1), mode='edge')
             r_n = 6371 + h_n
 
             b = np.pi / 2 - np.deg2rad(el)
@@ -400,13 +401,15 @@ class _ITU676_12_():
             for t, press, rho, r, delta, n_r in zip(
                     T_n, press_n, rho_n, r_n, delta_h, n_ratio):
                 a = - r * np.cos(b) + 0.5 * np.sqrt(
-                    4 * r**2 * np.cos(b)**2 + 8 * r * delta + 4 * delta**2)
+                    4 * r**2 * np.cos(b)**2 + 8 * r * delta + 4 * delta**2)  # Eq. 17
                 a_cos_arg = np.clip((-a**2 - 2 * r * delta - delta**2) /
                                     (2 * a * r + 2 * a * delta), -1, 1)
+                # Eq. 18a
                 alpha = np.pi - np.arccos(a_cos_arg)
                 gamma = self.gamma_exact(f, press, rho, t)
-                Agas += a * gamma
-                b = np.arcsin(n_r * np.sin(alpha))
+                Agas += a * gamma                                            # Eq. 13
+                b = np.arcsin(np.sin(alpha) *
+                              n_r)                           # Eq. 19a
 
             return Agas
 
@@ -430,7 +433,7 @@ class _ITU676_12_():
             gammaw = 0
 
         e = rho * T / 216.7
-        h0, hw = self.slant_inclined_path_equivalent_height(f, P + e)
+        h0, hw = self.slant_inclined_path_equivalent_height(f, P + e, rho, T)
 
         if 5 < el and el < 90:
             h0_p = h0 * (np.exp(-h1 / h0) - np.exp(-h2 / h0))
@@ -443,7 +446,7 @@ class _ITU676_12_():
             el1 = el
             Re = 8500  # TODO: change to ITU-R P 834
             el2 = np.rad2deg(
-                np.arccos(((Re + h1)/(Re + h2))*np.cos(np.deg2rad(el1))))
+                np.arccos(((Re + h1) / (Re + h2)) * np.cos(np.deg2rad(el1))))
 
             def xi(eli, hi):
                 return np.tan(np.deg2rad(eli)) * np.sqrt((Re + hi) / h0)
@@ -476,9 +479,9 @@ class _ITU676_12_():
         rho_ref = V_t / 2.38
         t_ref = 14 * np.log(0.22 * V_t / 2.38) + 3    # [Celsius]
 
-        a = (0.2048 * np.exp(- ((f - 22.43)/3.097)**2) +
-             0.2326 * np.exp(- ((f - 183.5)/4.096)**2) +
-             0.2073 * np.exp(- ((f - 325)/3.651)**2) - 0.1113)
+        a = (0.2048 * np.exp(- ((f - 22.43) / 3.097)**2) +
+             0.2326 * np.exp(- ((f - 183.5) / 4.096)**2) +
+             0.2073 * np.exp(- ((f - 325) / 3.651)**2) - 0.1113)
 
         b = 8.741e4 * np.exp(-0.587 * f) + 312.2 * f**(-2.38) + 0.723
         h = np.clip(h, 0, 4)
@@ -632,7 +635,7 @@ class _ITU676_11_():
         return gamma0, gammaw
 
     @classmethod
-    def slant_inclined_path_equivalent_height(self, f, p):
+    def slant_inclined_path_equivalent_height(self, f, p, rho=None, T=None):
         """
         """
         rp = p / 1013.25
@@ -694,15 +697,17 @@ class _ITU676_11_():
             return (A0 + Aw) / np.sin(np.deg2rad(el))
 
         else:
-            delta_h = 0.0001 * np.exp((np.arange(0, 923)) / 100)
-            h_n = np.cumsum(delta_h)
+            delta_h = 0.0001 * \
+                np.exp((np.arange(0, 922)) / 100)             # Eq. 21
+            h_n = 0.0001 * ((np.exp(np.arange(0, 922) / 100.0) -
+                             1.0) / (np.exp(1.0 / 100.0) - 1.0))
             T_n = standard_temperature(h_n).to(u.K).value
             press_n = standard_pressure(h_n).value
             rho_n = standard_water_vapour_density(h_n, rho_0=rho).value
 
-            e = rho * T / 216.7
-            n_n = radio_refractive_index(press_n, e, T).value
-            n_ratio = np.pad(n_n[1:], (0, 1), mode='edge') / n_n
+            e_n = rho_n * T_n / 216.7
+            n_n = radio_refractive_index(press_n, e_n, T_n).value
+            n_ratio = n_n / np.pad(n_n[1:], (0, 1), mode='edge')
             r_n = 6371 + h_n
 
             b = np.pi / 2 - np.deg2rad(el)
@@ -710,13 +715,15 @@ class _ITU676_11_():
             for t, press, rho, r, delta, n_r in zip(
                     T_n, press_n, rho_n, r_n, delta_h, n_ratio):
                 a = - r * np.cos(b) + 0.5 * np.sqrt(
-                    4 * r**2 * np.cos(b)**2 + 8 * r * delta + 4 * delta**2)
+                    4 * r**2 * np.cos(b)**2 + 8 * r * delta + 4 * delta**2)  # Eq. 17
                 a_cos_arg = np.clip((-a**2 - 2 * r * delta - delta**2) /
                                     (2 * a * r + 2 * a * delta), -1, 1)
+                # Eq. 18
                 alpha = np.pi - np.arccos(a_cos_arg)
                 gamma = self.gamma_exact(f, press, rho, t)
-                Agas += a * gamma
-                b = np.arcsin(n_r * np.sin(alpha))
+                Agas += a * gamma                                            # Eq. 20
+                b = np.arcsin(np.sin(alpha) *
+                              n_r)                           # Eq. 19
 
             return Agas
 
@@ -753,7 +760,7 @@ class _ITU676_11_():
             el1 = el
             Re = 8500  # TODO: change to ITU-R P 834
             el2 = np.rad2deg(
-                np.arccos(((Re + h1)/(Re + h2))*np.cos(np.deg2rad(el1))))
+                np.arccos(((Re + h1) / (Re + h2)) * np.cos(np.deg2rad(el1))))
 
             def xi(eli, hi):
                 return np.tan(np.deg2rad(eli)) * np.sqrt((Re + hi) / h0)
@@ -786,9 +793,9 @@ class _ITU676_11_():
         rho_ref = V_t / 3.67
         t_ref = 14 * np.log(0.22 * V_t / 3.67) + 3    # [Celsius]
 
-        a = (0.2048 * np.exp(- ((f - 22.43)/3.097)**2) +
-             0.2326 * np.exp(- ((f-183.5)/4.096)**2) +
-             0.2073 * np.exp(- ((f-325)/3.651)**2) - 0.113)
+        a = (0.2048 * np.exp(- ((f - 22.43) / 3.097)**2) +
+             0.2326 * np.exp(- ((f - 183.5) / 4.096)**2) +
+             0.2073 * np.exp(- ((f - 325) / 3.651)**2) - 0.113)
 
         b = 8.741e4 * np.exp(-0.587 * f) + 312.2 * f**(-2.38) + 0.723
         h = np.minimum(h, 4)
@@ -973,7 +980,7 @@ class _ITU676_10_():
         return gamma0, gammaw
 
     @classmethod
-    def slant_inclined_path_equivalent_height(self, f, p):
+    def slant_inclined_path_equivalent_height(self, f, p, rho=None, T=None):
         """
         """
         rp = p / 1013.0
@@ -1034,15 +1041,17 @@ class _ITU676_10_():
             return (A0 + Aw) / np.sin(np.deg2rad(el))
 
         else:
-            delta_h = 0.0001 * np.exp((np.arange(1, 923) - 1) / 100)
-            h_n = np.cumsum(delta_h)
+            delta_h = 0.0001 * \
+                np.exp((np.arange(0, 922)) / 100)             # Eq. 21
+            h_n = 0.0001 * ((np.exp(np.arange(0, 922) / 100.0) -
+                             1.0) / (np.exp(1.0 / 100.0) - 1.0))
             T_n = standard_temperature(h_n).to(u.K).value
             press_n = standard_pressure(h_n).value
             rho_n = standard_water_vapour_density(h_n, rho_0=rho).value
 
-            e = rho * T / 216.7
-            n_n = radio_refractive_index(press_n, e, T).value
-            n_ratio = np.pad(n_n[1:], (0, 1), mode='edge') / n_n
+            e_n = rho_n * T_n / 216.7
+            n_n = radio_refractive_index(press_n, e_n, T_n).value
+            n_ratio = n_n / np.pad(n_n[1:], (0, 1), mode='edge')
             r_n = 6371 + h_n
 
             b = np.pi / 2 - np.deg2rad(el)
@@ -1050,13 +1059,15 @@ class _ITU676_10_():
             for t, press, rho, r, delta, n_r in zip(
                     T_n, press_n, rho_n, r_n, delta_h, n_ratio):
                 a = - r * np.cos(b) + 0.5 * np.sqrt(
-                    4 * r**2 * np.cos(b)**2 + 8 * r * delta + 4 * delta**2)
+                    4 * r**2 * np.cos(b)**2 + 8 * r * delta + 4 * delta**2)  # Eq. 17
                 a_cos_arg = np.clip((-a**2 - 2 * r * delta - delta**2) /
                                     (2 * a * r + 2 * a * delta), -1, 1)
+                # Eq. 18
                 alpha = np.pi - np.arccos(a_cos_arg)
                 gamma = self.gamma_exact(f, press, rho, t)
-                Agas += a * gamma
-                b = np.arcsin(n_r * np.sin(alpha))
+                Agas += a * gamma                                            # Eq. 20
+                b = np.arcsin(np.sin(alpha) *
+                              n_r)                           # Eq. 19
 
             return Agas
 
@@ -1093,7 +1104,7 @@ class _ITU676_10_():
             el1 = el
             Re = 8500  # TODO: change to ITU-R P 834
             el2 = np.rad2deg(
-                np.arccos(((Re + h1)/(Re + h2))*np.cos(np.deg2rad(el1))))
+                np.arccos(((Re + h1) / (Re + h2)) * np.cos(np.deg2rad(el1))))
 
             def xi(eli, hi):
                 return np.tan(np.deg2rad(eli)) * np.sqrt((Re + hi) / h0)
@@ -1202,6 +1213,7 @@ class _ITU676_9_():
         return (self.gamma0_exact(f, p, rho, T) +
                 self.gammaw_exact(f, p, rho, T))
 
+
 __model = __ITU676__()
 
 
@@ -1281,7 +1293,7 @@ def gaseous_attenuation_terrestrial_path(r, f, el, rho, P, T, mode):
     [1] Attenuation by atmospheric gases:
     https://www.itu.int/rec/R-REC-P.676/en
     """
-    type_output = type(el)
+    type_output = get_input_type(el)
     r = prepare_quantity(r, u.km, 'Path Length')
     f = prepare_quantity(f, u.GHz, 'Frequency')
     el = prepare_quantity(prepare_input_array(el), u.deg, 'Elevation angle')
@@ -1289,7 +1301,7 @@ def gaseous_attenuation_terrestrial_path(r, f, el, rho, P, T, mode):
     P = prepare_quantity(P, u.hPa, 'Atospheric pressure')
     T = prepare_quantity(T, u.K, 'Temperature')
     val = __model.gaseous_attenuation_terrestrial_path(
-            r, f, el, rho, P, T, mode)
+        r, f, el, rho, P, T, mode)
     return prepare_output_array(val, type_output) * u.dB
 
 
@@ -1344,7 +1356,7 @@ def gaseous_attenuation_slant_path(f, el, rho, P, T, V_t=None, h=None,
     [1] Attenuation by atmospheric gases:
     https://www.itu.int/rec/R-REC-P.676/en
     """
-    type_output = type(el)
+    type_output = get_input_type(el)
     f = prepare_quantity(f, u.GHz, 'Frequency')
     el = prepare_quantity(prepare_input_array(el), u.deg, 'Elevation angle')
     rho = prepare_quantity(rho, u.g / u.m**3, 'Water vapor density')
@@ -1354,7 +1366,7 @@ def gaseous_attenuation_slant_path(f, el, rho, P, T, V_t=None, h=None,
                            'Integrated water vapour content')
     h = prepare_quantity(h, u.km, 'Altitude')
     val = __model.gaseous_attenuation_slant_path(
-            f, el, rho, P, T, V_t, h, mode)
+        f, el, rho, P, T, V_t, h, mode)
     return prepare_output_array(val, type_output) * u.dB
 
 
@@ -1404,7 +1416,7 @@ def gaseous_attenuation_inclined_path(f, el, rho, P, T, h1, h2, mode='approx'):
     """
     f = prepare_quantity(f, u.GHz, 'Frequency')
     el = prepare_quantity(el, u.deg, 'Elevation angle')
-    type_output = type(el)
+    type_output = get_input_type(el)
     rho = prepare_quantity(rho, u.g / u.m**3, 'Water vapor density')
     P = prepare_quantity(P, u.hPa, 'Atospheric pressure')
     T = prepare_quantity(T, u.K, 'Temperature')
@@ -1415,7 +1427,7 @@ def gaseous_attenuation_inclined_path(f, el, rho, P, T, h1, h2, mode='approx'):
     return prepare_output_array(val, type_output) * u.dB
 
 
-def slant_inclined_path_equivalent_height(f, p):
+def slant_inclined_path_equivalent_height(f, p, rho=7.5, T=298.15):
     """ Computes the equivalent height to be used for oxygen and water vapour
     gaseous attenuation computations.
 
@@ -1425,6 +1437,12 @@ def slant_inclined_path_equivalent_height(f, p):
         Frequency (GHz)
     p : number
         Percentage of the time the gaseous attenuation value is exceeded.
+    rho : number or Quantity
+        Water vapor density (g/m3)
+    P : number or Quantity
+        Atmospheric pressure (hPa)
+    T : number or Quantity
+        Absolute temperature (K)
 
     Returns
     -------
@@ -1437,10 +1455,12 @@ def slant_inclined_path_equivalent_height(f, p):
     https://www.itu.int/rec/R-REC-P.676/en
 
     """
-    type_output = type(f)
+    type_output = get_input_type(f)
     f = prepare_quantity(f, u.GHz, 'Frequency')
+    rho = prepare_quantity(rho, u.g / u.m**3, 'Water vapor density')
+    T = prepare_quantity(T, u.K, 'Temperature')
 
-    val = __model.slant_inclined_path_equivalent_height(f, p)
+    val = __model.slant_inclined_path_equivalent_height(f, p, rho, T)
     return prepare_output_array(val, type_output) * u.m
 
 
@@ -1481,7 +1501,7 @@ def zenit_water_vapour_attenuation(lat, lon, p, f, V_t=None, h=None):
     [1] Attenuation by atmospheric gases:
     https://www.itu.int/rec/R-REC-P.676/en
     """
-    type_output = type(lat)
+    type_output = get_input_type(lat)
     lat = prepare_input_array(lat)
     lon = prepare_input_array(lon)
     lon = np.mod(lon, 360)
@@ -1524,7 +1544,7 @@ def gammaw_approx(f, P, rho, T):
     [1] Attenuation by atmospheric gases:
     https://www.itu.int/rec/R-REC-P.676/en
     """
-    type_output = type(f)
+    type_output = get_input_type(f)
     f = prepare_quantity(f, u.GHz, 'Frequency')
     P = prepare_quantity(P, u.hPa, 'Atmospheric pressure ')
     rho = prepare_quantity(rho, u.g / u.m**3, 'Water vapour density')
@@ -1560,7 +1580,7 @@ def gamma0_approx(f, P, rho, T):
     [1] Attenuation by atmospheric gases:
     https://www.itu.int/rec/R-REC-P.676/en
     """
-    type_output = type(f)
+    type_output = get_input_type(f)
     f = prepare_quantity(f, u.GHz, 'Frequency')
     P = prepare_quantity(P, u.hPa, 'Atmospheric pressure')
     rho = prepare_quantity(rho, u.g / u.m**3, 'Water vapour density')
@@ -1597,7 +1617,7 @@ def gammaw_exact(f, P, rho, T):
     [1] Attenuation by atmospheric gases:
     https://www.itu.int/rec/R-REC-P.676/en
     """
-    type_output = type(f)
+    type_output = get_input_type(f)
     f = prepare_quantity(f, u.GHz, 'Frequency')
     P = prepare_quantity(P, u.hPa, 'Atmospheric pressure ')
     rho = prepare_quantity(rho, u.g / u.m**3, 'Water vapour density')
@@ -1633,7 +1653,7 @@ def gamma0_exact(f, P, rho, T):
     [1] Attenuation by atmospheric gases:
     https://www.itu.int/rec/R-REC-P.676/en
     """
-    type_output = type(f)
+    type_output = get_input_type(f)
     f = prepare_quantity(f, u.GHz, 'Frequency')
     P = prepare_quantity(P, u.hPa, 'Atmospheric pressure')
     rho = prepare_quantity(rho, u.g / u.m**3, 'Water vapour density')
@@ -1670,7 +1690,7 @@ def gamma_exact(f, P, rho, T):
     https://www.itu.int/rec/R-REC-P.676/en
     """
     f = prepare_quantity(f, u.GHz, 'Frequency')
-    type_output = type(f)
+    type_output = get_input_type(f)
 
     P = prepare_quantity(P, u.hPa, 'Atmospheric pressure ')
     rho = prepare_quantity(rho, u.g / u.m**3, 'Water vapour density')
