@@ -8,6 +8,7 @@ from astropy import units as u
 
 from itur.utils import (prepare_input_array,
                         prepare_output_array,
+                        get_input_type,
                         prepare_quantity)
 
 
@@ -86,21 +87,21 @@ class _ITU835_6():
         """
         h_p = 6356.766 * h / (6356.766 + h)
         T = np.where(h_p <= 11, 288.15 - 6.5 * h_p,
-            np.where(np.logical_and(11 <= h_p, h_p < 20),
+            np.where(np.logical_and(11 < h_p, h_p <= 20),
                      216.65,
-            np.where(np.logical_and(20 <= h_p, h_p < 32),
+            np.where(np.logical_and(20 < h_p, h_p <= 32),
                      216.65 + (h_p - 20),
-            np.where(np.logical_and(32 <= h_p, h_p < 47),
-                     216.65 + 2.8 * (h_p - 32),
-            np.where(np.logical_and(47 <= h_p, h_p < 51),
+            np.where(np.logical_and(32 < h_p, h_p <= 47),
+                     228.65 + 2.8 * (h_p - 32),
+            np.where(np.logical_and(47 < h_p, h_p <= 51),
                      270.65,
-            np.where(np.logical_and(51 <= h_p, h_p < 71),
+            np.where(np.logical_and(51 < h_p, h_p <= 71),
                      270.65 - 2.8 * (h_p - 51),
-            np.where(np.logical_and(71 <= h_p, h_p < 84.852),
+            np.where(np.logical_and(71 < h_p, h_p <= 84.852),
                      214.65 - 2.0 * (h_p - 71),
-            np.where(np.logical_and(86 <= h, h < 91),
+            np.where(np.logical_and(86 <= h, h <= 91),
                      186.8673,
-            np.where(np.logical_and(91 <= h, h < 100),
+            np.where(np.logical_and(91 < h, h <= 100),
                      263.1905 - 76.3232 * np.sqrt((1 - ((h - 91)/19.9429)**2)),
                      195.08134433524688)))))))))
 
@@ -115,24 +116,24 @@ class _ITU835_6():
         P = np.where(h_p <= 11,
                      1013.25 * np.power((288.15 / (288.15 - 6.5 * h_p)),
                      (-34.1632 / 6.5)),
-            np.where(np.logical_and(11 <= h_p, h_p < 20),
+            np.where(np.logical_and(11 < h_p, h_p <= 20),
                      226.3226 * np.exp(-34.1632 * (h_p - 11) / 216.65),
-            np.where(np.logical_and(20 <= h_p, h_p < 32),
+            np.where(np.logical_and(20 < h_p, h_p <= 32),
                      54.74980 * (216.65 / (216.65 + (h_p - 20))) ** 34.1632,
-            np.where(np.logical_and(32 <= h_p, h_p < 47),
-                     8.680422 * (228.65 / (228.65 - 2.8 * (h_p - 32))) **
+            np.where(np.logical_and(32 < h_p, h_p <= 47),
+                     8.680422 * (228.65 / (228.65 + 2.8 * (h_p - 32))) **
                      (34.1632 / 2.8),
-            np.where(np.logical_and(47 <= h_p, h_p < 51),
+            np.where(np.logical_and(47 < h_p, h_p <= 51),
                      1.109106 * np.exp(-34.1632 * (h_p - 47) / 270.65),
-            np.where(np.logical_and(51 <= h_p, h_p < 71),
+            np.where(np.logical_and(51 < h_p, h_p <= 71),
                      0.6694167 * np.power((270.65 / (270.65 - 2.8 * (h_p - 51))),
                      (-34.1632 / 2.8)),
-            np.where(np.logical_and(71 <= h_p, h_p < 84.852),
+            np.where(np.logical_and(71 < h_p, h_p <= 84.852),
                      0.03956649 * np.power((214.65 / (214.65 - 2.0 * (h_p - 71))),
                      (-34.1632 / 2.0)),
-            np.where(np.logical_and(86 <= h, h < 100),
+            np.where(np.logical_and(86 <= h, h <= 100),
                      np.exp(95.571899 -4.011801 * h + 6.424731e-2 * h**2 -
-                            4.789660e-4 * h**3 + 1.1340543e-6 * h**4),
+                            4.789660e-4 * h**3 + 1.340543e-6 * h**4),
                      1e-62)))))))).astype(float)
 
         return P
@@ -708,7 +709,7 @@ def temperature(lat, h, season='summer'):
 
     """
     global __model
-    type_output = type(lat)
+    type_output = get_input_type(lat)
     lat = prepare_input_array(lat)
     h = prepare_quantity(h, u.km, 'Height')
     val = __model.temperature(lat, h, season)
@@ -745,7 +746,7 @@ def pressure(lat, h, season='summer'):
     https://www.itu.int/rec/R-REC-P.835/en
     """
     global __model
-    type_output = type(lat)
+    type_output = get_input_type(lat)
     lat = prepare_input_array(lat)
     h = prepare_quantity(h, u.km, 'Height')
     val = __model.pressure(lat, h, season)
@@ -784,7 +785,7 @@ def water_vapour_density(lat, h, season='summer'):
     https://www.itu.int/rec/R-REC-P.835/en
     """
     global __model
-    type_output = type(lat)
+    type_output = get_input_type(lat)
     lat = prepare_input_array(lat)
     h = prepare_quantity(h, u.km, 'Height')
     val = __model.water_vapour_density(lat, h, season)
@@ -860,7 +861,7 @@ def standard_pressure(h, T_0=288.15, P_0=1013.25):
     """
     global __model
 
-    type_output = type(h)
+    type_output = get_input_type(h)
     h = prepare_quantity(h, u.km, 'Height')
     h = np.atleast_1d(h)
     T_0 = prepare_quantity(T_0, u.Kelvin, 'Surface temperature')
